{
  description = "Nix configuration";
 
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs";
 
    nix-darwin.url = "github:lnl7/nix-darwin/master";
    nix-darwin.inputs.nixpkgs.follows = "nixpkgs";
 
    home-manager.url = "github:nix-community/home-manager";
    home-manager.inputs.nixpkgs.follows = "nixpkgs";
    
    lix-module = {
      url = "https://git.lix.systems/lix-project/nixos-module/archive/2.93.1.tar.gz";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    
    spicetify-nix.url = "github:Gerg-L/spicetify-nix";
  };
 
  outputs = inputs @ { self, spicetify-nix, ... }: let
    nixpkgsConfig = {
      config.allowUnfree = true;
    };
  in {
    darwinConfigurations = let
      inherit (inputs.nix-darwin.lib) darwinSystem;
    in {
      Ethans-MacBook-Air = darwinSystem {
        system = "aarch64-darwin";

        specialArgs = { inherit inputs; };

        modules = [
          ./hosts/Ethans-MacBook-Air/configuration.nix
          inputs.home-manager.darwinModules.home-manager
          inputs.lix-module.nixosModules.default
          {
            nixpkgs = nixpkgsConfig;

            home-manager = {
              useGlobalPkgs = true;
              useUserPackages = true;
              extraSpecialArgs = { inherit spicetify-nix; };
              users.ethanreece = {
                imports = [
                  (import ./home/home.nix)
                  spicetify-nix.homeManagerModules.spicetify
                ];
              };
            };
          }
        ];
      };
    };
  };
}

